//**********************************************************************
//            LCT-METER/PULSER - HLAVICKOVY SOUBOR
//**********************************************************************
// (c) OK1XGL 2004
// verze 1.00 - uvodni verze 10.1.2004
// verze 1.01 - pridano ukladani  vlastni Cp/Lp do pameti EEPROM
//            - pridano ukladani stavu (mod, parametry modu ) do pameti EEROM
//

#use delay (clock=4000000,restart_wdt)
#fuses XT,NOWDT,NOPROTECT,NOBROWNOUT,NOLVP

// LCD display
#define LCD_RS          PIN_A0      /* rizeni registru LCD displeje */
#define LCD_E           PIN_A1      /* enable LCD displeje */
#define LCD_DATA_LSB    PIN_A2      /* pripojeni LSB bitu datoveho portu LCD displeje (celkem 4 bity vzestupne za sebou) */
#define LCD_CHAR_DELTA "\x80\x80\x80\x04\x0A\x11\x1F\x80"      /* symbol delta */
#define LCD_CHAR_DEC   "\x0E\x0A\x0E\x80\x80\x80\x80\x80"      /* symbol stupen */

// rele pro prepinani modu mereni
#define RE1_A           PIN_C4
#define RE1_B           PIN_C7
#define RE2_A           PIN_C5
#define RE2_B           PIN_C6
#define RELE_PULSE      10          /* delka prepinaciho pulzu pro rele v ms jednotkach */

// tlacitka (libovolne na brane B)
#define NUL_KEY         PIN_B7      /* pro nulovani pocatecni C nebo L  NEBO T, pri generovani pulzu prepina sirku pulzu */
#define MODE_KEY        PIN_B6      /* pro prepinani modu mereni */

// pulser (nelze zmenit, vystup PWM a CPP1 jednotky je jen zde)
#define PULSER_PIN      PIN_C2      /* vystup pulseru */

// teplomer (POZOR NA VSTUPY SE SHMIDTOVYM OBVODEM, NELZE POUZIT!!!!!)
#define TM_PIN          PIN_B0     /* pin, na kterem je teplomer pripojen */
#bit    TM_PIN_BIT =    PORTB.0    /* totez, ale definovan jako bit */
#define TM_PULLUP       PIN_B1     /* pullup pro teplomer */

// konstanty pro mereni frekvence
#define  TIME_1S_L      0xff-194   /* urcuje dobu, za kterou vyprsi timer0 (zde 50ms),meri interval doby mereni  frekvence */
#define  TIME_1S_H      5          /* rozsiruje timer0, aby bylo mozne odmerit delsi casy zde 250ms */
#define  CORIG          21         /* pro korekci intervalu doby mereni frekvence aby byla presne (vliv doby preruseni a nepresnost oscilatoru) */
#define  FREQ_CALM_TIME 2000       /* cas pro ustaleni frekvence oscialtoru v ms jednotkach */
#define  C_CALIB        996        /* hodnota kalibracniho kondenzatoru v pF */
#define  F_CORRECT      4          /* korekce zmereneho kmitoctu, aby byl v Hz a ne v napr. v 4Hz jednotkach jako zde */

// adresy parametru v pameti EEROM
#define  CP_ADR_LOW     0          /* pro ulozeni vlastni kapacity  4 bajty*/
#define  LP_ADR_LOW     4          /* pro ulozeni vlastni indukcnosti 4 bajty*/
#define  MODE_ADR       8          /* uchovani modu zarizeni viz promenna mode */
#define  WIDTH_ADR      9          /* uchovani sirky pulzu v modu pulser viz promenna pulse_width */

// konstanty pro mereni teploty
#define  CONV_WAIT      4          /* cas cekani az teplomer zmeri teplotu v jednotkach doby citani impulzu pri mereni frekvence */

// konstanty pro promennou mode ve funkci main()
#define  MODE_L         0        /* mereni indukcnosti */
#define  MODE_C         1        /* mereni kapacity */
#define  MODE_T         2        /* mereni teploty */
#define  MODE_P         3        /* generator pulzu */

// konstanty pro promennou pulse_width ve funkci pulser()
#define  P_10US         0
#define  P_20US         1
#define  P_50US         2
#define  P_100US        3
#define  P_200US        4
#define  P_500US        5
#define  P_1MS          6
#define  P_2MS          7
#define  P_5MS          8
#define  P_10MS         9
#define  P_20MS         10
#define  P_50MS         11
#define  P_500MS        12
#define  P_5US          13

// konstanty pro promennou status ve funkci measure_T()
#define  T_WAIT         0        /* odmer 1000 ms */
#define  T_MEASURE      1        /* posli prikaz ke zmereni teploty */
#define  T_DISPLAY      2        /* precti zmerenou teplotu a zobraz ji */

// konstanty pro promennou freq_done
#define  F_PEACE         0       /* klidovy stav tuto hodnotu nemenit !!!! */
#define  F_DONE          1       /* mereni frekvence dokonceno */
#define  F_KEY           2       /* stisknuto tlacitko, mereni frekvence preruseno */

// texty zobrazovane na 1.radku LCD displeje
#define  VERSION_MSG          " Version 1.01"
#define  COPYRIGHT_MSG        "(c) OK1XGL 2004"
#define  CALIB_MSG            "  Calibration"
#define  CONNECT_LX_MSG       " Connect Lx !!!"
#define  ERROR_CX_MSG         "  Error Cx !!!"
#define  CONNECT_TEMP_MSG     "  Connect temp"
#define  PULSE_5us_MSG        "  5us (100KHz)"
#define  PULSE_10us_MSG       "  10us (50KHz)"
#define  PULSE_20us_MSG       "  20us (25KHz)"
#define  PULSE_50us_MSG       "  50us (10KHz)"
#define  PULSE_100us_MSG      "  100us (5KHz)"
#define  PULSE_200us_MSG      " 200us (2.5KHz)"
#define  PULSE_500us_MSG      "  500us (1KHz)"
#define  PULSE_1ms_MSG        "  1ms  (500Hz)"
#define  PULSE_2ms_MSG        "  2ms  (250Hz)"
#define  PULSE_5ms_MSG        "  5ms  (100Hz)"
#define  PULSE_10ms_MSG       "  10ms  (50Hz)"
#define  PULSE_20ms_MSG       "  20ms  (25Hz)"
#define  PULSE_50ms_MSG       "  50ms  (10Hz)"
#define  PULSE_500ms_MSG      "  500ms  (1Hz)"

// texty zobrazovane na 2. radku LCD displeje
#define  MODE_CX_NULL_MSG     "MODE   Cx   NULL"
#define  MODE_LX_NULL_MSG     "MODE   Lx   NULL"
#define  MODE_TMP_NULL_MSG    "MODE  +TMP  NULL"
#define  MODE_PLZ_WIDTH_MSG   "MODE  +PLZ WIDTH"

// konstantni pole pro prefix radu
int8 const C_PREFIX[4] = {'p','n','u','m'};
char const L_PREFIX[4] = {'n','u','m',' '};

// uvodni nastaveni parametru v pameti eeprom
#rom  0x2100={0,0,0,0,0,0,0,0,MODE_C,P_5US}

// globalni promenne
int8     freq_done;             // stav procesu mereni frekvence
int8     W_TMP;                 // pro ulozeni W v prerusovaci rutine
int8     F_TMP;                 // pro ulozeni F v prerusovaci rutine
int8     PCLATH_TMP;            // pro ulozeni PCLATH v prerusovaci rutine
int8     INT_TMP;               // pomocna promenna pro preruseni
int8     sampler_H;             // rozsireni timeru0 ,ktery meri dobu citani impulzu mericiho oscilatoru v tmr0 jednotkach
int8     counter_H;             // rozsireni timeru1, ktery slouzi pro citani impulzu mericiho oscilatoru

// End of File
